diff --git a/phpgwapi/inc/class.html.inc.php b/phpgwapi/inc/class.html.inc.php
index 74ea31f2a9..01116d4f26 100644
--- a/phpgwapi/inc/class.html.inc.php
+++ b/phpgwapi/inc/class.html.inc.php
@@ -199,7 +199,7 @@ class html
* @param array $arr array with items to select, eg. $arr = array ( 'y' => 'yes','n' => 'no','m' => 'maybe');
* @param boolean $no_lang NOT run the labels of the options through lang(), default false=use lang()
* @param string $options additional options (e.g. 'width')
* @param int $multiple number of lines for a multiselect, default 0 = no multiselect
* @return string to set for a template or to echo into html page
*/
function select($name, $key, $arr=0,$no_lang=false,$options='',$multiple=0)
@@ -216,12 +216,16 @@ class html
$name .= '[]';
}
}
+ elseif($multiple < 0)
+ {
+ $options .= ' size="'.abs($multiple).'"';
+ }
$out = "
@@ -199,7 +199,7 @@ class html
* @param boolean $no_lang NOT run the labels of the options through lang(), default false=use lang()
* @param string $options additional options (e.g. 'width')
- * @param int $multiple number of lines for a multiselect, default 0 = no multiselect
+ * @param int $multiple number of lines for a multiselect, default 0 = no multiselect, < 0 sets size without multiple
* @return string to set for a template or to echo into html page
*/